@@ -2,13 +2,11 @@ package YAML::Any;
 
 use 5.005003;
 use strict;
-use Exporter ();
+use base 'Exporter';
 
-$YAML::Any::VERSION   = '0.69_01';
-$YAML::Any::VERSION   = eval $YAML::Any::VERSION;
-@YAML::Any::ISA       = 'Exporter';
-@YAML::Any::EXPORT    = qw(Dump Load);
+@YAML::Any::EXPORT = qw(Dump Load);
 @YAML::Any::EXPORT_OK = qw(DumpFile LoadFile);
+$YAML::Any::VERSION = '0.67';
 
 my @dump_options = qw(
     UseCode
@@ -27,7 +25,6 @@ my @dump_options = qw(
     Purity
     Stringify
 );
-
 my @load_options = qw(
     UseCode
     LoadCode
